@@ -4,9 +4,10 @@ from __future__ import (absolute_import, division, print_function)
 import numpy as np
 import pytest
 from .. import Backend
+from . import AVAILABLE_BACKENDS
 
 
-@pytest.mark.parametrize('key', Backend.backends.keys())
+@pytest.mark.parametrize('key', AVAILABLE_BACKENDS)
 def test_Matrix(key):
     be = Backend(key)
     x = be.Symbol('x')
@@ -17,7 +18,7 @@ def test_Matrix(key):
     assert mat[1, 1] == 3
 
 
-@pytest.mark.parametrize('key', Backend.backends.keys())
+@pytest.mark.parametrize('key', AVAILABLE_BACKENDS)
 def test_Matrix_jacobian(key):
     be = Backend(key)
     x = be.Symbol('x')
